==> testmill-0.9.6.tar.gz: testmill-0.9.6/lib/testmill/test/test_restore.py <==
# Copyright 2012-2013 Ravello Systems, Inc.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import, print_function

import os
from nose import SkipTest

from testmill.main import main
from testmill.state import env
from testmill.test import *


class TestRestore(SystemTestSuite):
    """Test the "ravtest restore" command."""

    @classmethod
    def setup_class(cls):
        args = get_common_args()
        args += ['-m', 'platformtest.yml', 'run', 'platformtest', '--dry-run']
        with env.new():  # do not pollute test-global env
            status = main(args)
            if status != 0:
                raise SkipTest('Could not start platformtest app.')
            project, defname, instance = env.application['name'].split(':')
            appname = '{}:{}'.format(defname, instance)
            vms = [vm['name'] for vm in env.appdef['vms']]
        cls.appname = appname
        args = get_common_args()
        args += ['-m', 'platformtest.yml', 'save', self.appname, '-y']
        with env.new():
            status = main(args)
            if status != 0:
                raise SkipTest('Could not create blueprint.')
            project, defname, instance = env.blueprint['name'].split(':')
            bpname = '{}:{}'.format(defname, instance)
        cls.bpname = bpname

    def test_restore(self):
        args = get_common_args()
        args += ['-m', 'platformtest.yml', 'restore', self.bpname]
        # XXX: complete

    @classmethod
    def teardown_class(cls):
        args = get_common_args()
        args += ['-m', 'platformtest.yml', '-y', 'clean', '-b']
        with env.new():
            main(args)

==> testmill-0.9.8.tar.gz: testmill-0.9.8/lib/testmill/test/test_restore.py <==
# Copyright 2012-2013 Ravello Systems, Inc.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import, print_function

import os
from nose import SkipTest

from testmill.main import main
from testmill.state import env
from testmill.test import *


class TestRestore(SystemTestSuite):
    """Test the "ravtest restore" command."""

    @classmethod
    def setup_class(cls):
        args = get_common_args()
        args += ['-m', 'platformtest.yml', 'run', 'platformtest', '--dry-run']
        with env.new():  # do not pollute test-global env
            status = main(args)
            if status != 0:
                raise SkipTest('Could not start platformtest app.')
            project, defname, instance = env.application['name'].split(':')
            appname = '{}:{}'.format(defname, instance)
            vms = [vm['name'] for vm in env.appdef['vms']]
        cls.appname = appname
        args = get_common_args()
        args += ['-m', 'platformtest.yml', 'save', cls.appname, '-y']
        with env.new():
            status = main(args)
            if status != 0:
                raise SkipTest('Could not create blueprint.')
            project, defname, instance = env.blueprint['name'].split(':')
            bpname = '{}:{}'.format(defname, instance)
        cls.bpname = bpname

    def test_restore(self):
        args = get_common_args()
        args += ['-m', 'platformtest.yml', 'restore', self.bpname]
        # XXX: complete

    @classmethod
    def teardown_class(cls):
        args = get_common_args()
        args += ['-m', 'platformtest.yml', '-y', 'clean', '-b']
        with env.new():
            main(args)
